﻿using System.Collections.Generic;
using System.ComponentModel;
using System;
using System.Linq;

namespace VCExploratory
{
    public class MockDataService
    {
        public const int RootDataCount = 200;

        private static int _id = 0;
        private static string _dataText = "data";
        private static List<TestData> _data;


        static MockDataService()
        {
            _data = new List<TestData>(RootDataCount);

            string field;
            var random = new Random();
            for (int i = 0; i < RootDataCount; i++)
            {
                field = _id + _dataText + i;

                _data.Add(new TestData() { StringData = field, IntegerData = random.Next(1, RootDataCount), BoolData = (i % 2 == 0) });
            }
        }

        public static IEnumerable<TestData> GetRootData(int startIndex, int itemsCount)
        {
            return GetRootData(startIndex, itemsCount, null);
        }

        public static IEnumerable<TestData> GetRootData(int startIndex, int itemsCount, SortDescriptionCollection sortDescriptionCollection)
        {
            if (sortDescriptionCollection == null || sortDescriptionCollection.Count == 0)
            {
                return _data.Skip(startIndex).Take(itemsCount);
            }

            var description =
                sortDescriptionCollection.SingleOrDefault(d => string.Equals(d.PropertyName, "IntegerData"));

            if (description == null)
            {
                throw new ArgumentException("Cannot sort by the specified sort descriptions");
            }

            if (description.Direction == ListSortDirection.Ascending)
            {
                return _data.OrderBy(d => d.IntegerData).Skip(startIndex).Take(itemsCount);
            }
            else
            {
                return _data.OrderByDescending(d => d.IntegerData).Skip(startIndex).Take(itemsCount);
            }
        }
    }
}
